_me = frm_alert.prototype;
function frm_alert(){};

/**
 * ALERT!!!
 */
_me.__constructor = async function(aResponse, sLabel1, sLabel2, aSubstitution) {
	var me = this;

	this._modal(true);
	this._dockable(false);
	this._resizable(false);

    await this._draw('frm_confirm', 'main');

	this._title(sLabel1 || 'ALERTS::ALERT');

    if (typeof aSubstitution == 'string')
		this.obj_label._value(aSubstitution);
    else
	if (sLabel2)
		this.obj_label._value(getLang(sLabel2, aSubstitution));

	// Create 'OK' button
	await this._create('x_btn_ok', 'obj_button', 'footer', 'noborder ok');
	this.x_btn_ok._value('FORM_BUTTONS::OK');
	this.x_btn_ok._onclick = function() {
		executeCallbackFunction(aResponse);
		me._destruct();
	};

	this.x_btn_ok._focus();

	this._onclose = async function (bClose){
		if (bClose && aResponse)
			if (await executeCallbackFunction(aResponse) === false)
				return false;

		return true;
	};

	this._size(450,'auto',true);
};